﻿/*************************************\
 *         Ordnerüberwachung         *
 *                                   *
 * Kapitel: Erweiterte               *
 *           Programmierthemen       *
 * Zuordnung: C#-Buch V2.0 14.4      *
 *                                   *
 *  Copyright 2015 by Benjamin Jung  *
\*************************************/
using System;
using System.IO;
using System.Windows.Forms;

namespace CSV20.Ordnerüberwachung
{
    public partial class Form1 : Form
    {
        private FileSystemWatcher oFileWatch = new FileSystemWatcher();

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            if (folderBrowserDialogOrdner.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                // Ordner-Pfad und Filter setzen
                oFileWatch.Path = folderBrowserDialogOrdner.SelectedPath;
                oFileWatch.Filter = "*.*";
                // Events registrieren (wir könnten auch für jedes Event eine eigene Event-Funktion verwenden)
                oFileWatch.Created += new FileSystemEventHandler(oFileWatch_Action);
                oFileWatch.Changed += new FileSystemEventHandler(oFileWatch_Action);
                oFileWatch.Deleted += new FileSystemEventHandler(oFileWatch_Action);
                // Event für Umbennung registrieren (wir benötigen die RenamedEventArgs um den 
                // alten und neuen Namen der Datei / des Ordners zu erhalten)
                oFileWatch.Renamed += new RenamedEventHandler(oFileWatch_ActionRename);
                // Unterverzeichnisse mit einbeziehen
                oFileWatch.IncludeSubdirectories = true;
                // Events aktivieren
                oFileWatch.EnableRaisingEvents = true;
                // Fenster minimieren und danach wieder in normale Fenstergröße zurückkehren,
                // dies ist ein Trick, sodass wir die Anwendung wieder in den Vordergrund bekommen
                this.WindowState = FormWindowState.Minimized;
                this.WindowState = FormWindowState.Normal;
            }
            else // Bei Abbruch, Fenster schließen
                Close();
        }

        void oFileWatch_Action(object sender, FileSystemEventArgs e)
        {
            this.Invoke((MethodInvoker)delegate
            {
                textBoxLog.Text += DateTime.Now.ToString();

                switch (e.ChangeType)
                {
                    case WatcherChangeTypes.Created:
                        textBoxLog.Text += " Erstellt ";
                        break;

                    case WatcherChangeTypes.Changed:
                        textBoxLog.Text += " Geändert ";
                        break;

                    case WatcherChangeTypes.Deleted:
                        textBoxLog.Text += " Gelöscht ";
                        break;
                }

                textBoxLog.Text += e.FullPath + "\r\n";

                textBoxLog.Select(textBoxLog.Text.Length, 0);
                textBoxLog.ScrollToCaret();
            });
        }

        void oFileWatch_ActionRename(object sender, RenamedEventArgs e)
        {
            this.Invoke((MethodInvoker)delegate
            {
                textBoxLog.Text += DateTime.Now.ToString();

                textBoxLog.Text += " Umbenannt ";

                textBoxLog.Text += e.OldFullPath + " zu ";

                textBoxLog.Text += e.FullPath + "\r\n";

                textBoxLog.Select(textBoxLog.Text.Length, 0);
                textBoxLog.ScrollToCaret();
            });
        }
    }
}